==> egroupware_1.0.00.006-1.dfsg.orig.tar.gz: egroupware-1.0.00.006-1.dfsg/felamimail/setup/tables_baseline.inc.php <==
<?php
  /**************************************************************************\
  * phpGroupWare                                                             *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: tables_baseline.inc.php,v 1.4 2003/08/31 18:01:00 lkneschke Exp $ */

	$phpgw_baseline = array(
		'phpgw_felamimail_cache' => array(
			'fd' => array(
				'accountid' 	=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'hostname' 	=> array('type' => 'varchar', 'precision' => 60, 'nullable' => false),
				'accountname' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'foldername' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'uid' 		=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'subject'	=> array('type' => 'text'),
				'striped_subject'=> array('type' => 'text'),
				'sender_name'	=> array('type' => 'varchar', 'precision' => 120),
				'sender_address'=> array('type' => 'varchar', 'precision' => 120),
				'to_name'	=> array('type' => 'varchar', 'precision' => 120),
				'to_address'	=> array('type' => 'varchar', 'precision' => 120),
				'date'		=> array('type' => 'varchar', 'precision' => 120),
				'size'		=> array('type' => 'int', 'precision' => 4),
				'attachments'	=> array('type' => 'varchar', 'precision' =>120)
			),
			'pk' => array('accountid','hostname','accountname','foldername','uid'),
			'fk' => array(),
			'ix' => array(),
			'uc' => array()
		),
		'phpgw_felamimail_folderstatus' => array(
			'fd' => array(
				'accountid' 	=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'hostname' 	=> array('type' => 'varchar', 'precision' => 60, 'nullable' => false),
				'accountname' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'foldername' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'messages' 	=> array('type' => 'int', 'precision' => 4),
				'recent'	=> array('type' => 'int', 'precision' => 4),
				'unseen'	=> array('type' => 'int', 'precision' => 4),
				'uidnext'	=> array('type' => 'int', 'precision' => 4),
				'uidvalidity'	=> array('type' => 'int', 'precision' => 4)
			),
			'pk' => array('accountid','hostname','accountname','foldername'),
			'fk' => array(),
			'ix' => array(),
			'uc' => array()
		)
	);
?>

==> egroupware_1.2-105.dfsg.orig.tar.gz: egroupware-1.2-105.dfsg/felamimail/setup/tables_baseline.inc.php <==
<?php
  /**************************************************************************\
  * eGroupWare                                                               *
  * http://www.egroupware.org                                                *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: tables_baseline.inc.php 16293 2004-08-09 11:07:58Z reinerj $ */

	$phpgw_baseline = array(
		'phpgw_felamimail_cache' => array(
			'fd' => array(
				'accountid' 	=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'hostname' 	=> array('type' => 'varchar', 'precision' => 60, 'nullable' => false),
				'accountname' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'foldername' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'uid' 		=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'subject'	=> array('type' => 'text'),
				'striped_subject'=> array('type' => 'text'),
				'sender_name'	=> array('type' => 'varchar', 'precision' => 120),
				'sender_address'=> array('type' => 'varchar', 'precision' => 120),
				'to_name'	=> array('type' => 'varchar', 'precision' => 120),
				'to_address'	=> array('type' => 'varchar', 'precision' => 120),
				'date'		=> array('type' => 'varchar', 'precision' => 120),
				'size'		=> array('type' => 'int', 'precision' => 4),
				'attachments'	=> array('type' => 'varchar', 'precision' =>120)
			),
			'pk' => array('accountid','hostname','accountname','foldername','uid'),
			'fk' => array(),
			'ix' => array(),
			'uc' => array()
		),
		'phpgw_felamimail_folderstatus' => array(
			'fd' => array(
				'accountid' 	=> array('type' => 'int', 'precision' => 4, 'nullable' => false),
				'hostname' 	=> array('type' => 'varchar', 'precision' => 60, 'nullable' => false),
				'accountname' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'foldername' 	=> array('type' => 'varchar', 'precision' => 200, 'nullable' => false),
				'messages' 	=> array('type' => 'int', 'precision' => 4),
				'recent'	=> array('type' => 'int', 'precision' => 4),
				'unseen'	=> array('type' => 'int', 'precision' => 4),
				'uidnext'	=> array('type' => 'int', 'precision' => 4),
				'uidvalidity'	=> array('type' => 'int', 'precision' => 4)
			),
			'pk' => array('accountid','hostname','accountname','foldername'),
			'fk' => array(),
			'ix' => array(),
			'uc' => array()
		)
	);
?>
